@@ -8,6 +8,7 @@ import           Test.Hspec
 import qualified Test.DocTest.Internal.Interpreter as Interpreter
 import           Test.DocTest.Internal.Interpreter
   (haveInterpreterKey, ghcInfo, withInterpreter)
+import           Test.DocTest.Internal.Logging (noLogger)
 
 main :: IO ()
 main = hspec spec
@@ -25,8 +26,8 @@ spec = do
         (||) <$> (== Just "YES") <*> (== Just "NO")
 
   describe "safeEval" $ do
-    it "evaluates an expression" $ withInterpreter [] $ \ghci -> do
+    it "evaluates an expression" $ withInterpreter noLogger [] $ \ghci -> do
       Interpreter.safeEval ghci "23 + 42" `shouldReturn` Right "65\n"
 
-    it "returns Left on unterminated multiline command" $ withInterpreter [] $ \ghci -> do
+    it "returns Left on unterminated multiline command" $ withInterpreter noLogger [] $ \ghci -> do
       Interpreter.safeEval ghci ":{\n23 + 42" `shouldReturn` Left "unterminated multiline command"
